@@ -36,4 +36,10 @@ class ListScenesRequest(RoaRequest):
 		return self.get_path_params().get('InstanceId')
 
 	def set_InstanceId(self,InstanceId):
-		self.add_path_param('InstanceId',InstanceId)
\ No newline at end of file
+		self.add_path_param('InstanceId',InstanceId)
+
+	def get_Status(self):
+		return self.get_query_params().get('Status')
+
+	def set_Status(self,Status):
+		self.add_query_param('Status',Status)
\ No newline at end of file
